==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/cloud_run_v2_service/CloudRunV2ServiceTemplateVolumes.java <==
package com.hashicorp.cdktf.providers.google.cloud_run_v2_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:39.130Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.cloudRunV2Service.CloudRunV2ServiceTemplateVolumes")
@software.amazon.jsii.Jsii.Proxy(CloudRunV2ServiceTemplateVolumes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CloudRunV2ServiceTemplateVolumes extends software.amazon.jsii.JsiiSerializable {

    /**
     * Volume's name.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#name CloudRunV2Service#name}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * cloud_sql_instance block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#cloud_sql_instance CloudRunV2Service#cloud_sql_instance}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance getCloudSqlInstance() {
        return null;
    }

    /**
     * secret block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#secret CloudRunV2Service#secret}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret getSecret() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CloudRunV2ServiceTemplateVolumes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudRunV2ServiceTemplateVolumes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CloudRunV2ServiceTemplateVolumes> {
        java.lang.String name;
        com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance cloudSqlInstance;
        com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret secret;

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateVolumes#getName}
         * @param name Volume's name. This parameter is required.
         *             Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#name CloudRunV2Service#name}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateVolumes#getCloudSqlInstance}
         * @param cloudSqlInstance cloud_sql_instance block.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#cloud_sql_instance CloudRunV2Service#cloud_sql_instance}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudSqlInstance(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance cloudSqlInstance) {
            this.cloudSqlInstance = cloudSqlInstance;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateVolumes#getSecret}
         * @param secret secret block.
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#secret CloudRunV2Service#secret}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder secret(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret secret) {
            this.secret = secret;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudRunV2ServiceTemplateVolumes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CloudRunV2ServiceTemplateVolumes build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CloudRunV2ServiceTemplateVolumes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudRunV2ServiceTemplateVolumes {
        private final java.lang.String name;
        private final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance cloudSqlInstance;
        private final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret secret;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cloudSqlInstance = software.amazon.jsii.Kernel.get(this, "cloudSqlInstance", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance.class));
            this.secret = software.amazon.jsii.Kernel.get(this, "secret", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.cloudSqlInstance = builder.cloudSqlInstance;
            this.secret = builder.secret;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance getCloudSqlInstance() {
            return this.cloudSqlInstance;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret getSecret() {
            return this.secret;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("name", om.valueToTree(this.getName()));
            if (this.getCloudSqlInstance() != null) {
                data.set("cloudSqlInstance", om.valueToTree(this.getCloudSqlInstance()));
            }
            if (this.getSecret() != null) {
                data.set("secret", om.valueToTree(this.getSecret()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.cloudRunV2Service.CloudRunV2ServiceTemplateVolumes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudRunV2ServiceTemplateVolumes.Jsii$Proxy that = (CloudRunV2ServiceTemplateVolumes.Jsii$Proxy) o;

            if (!name.equals(that.name)) return false;
            if (this.cloudSqlInstance != null ? !this.cloudSqlInstance.equals(that.cloudSqlInstance) : that.cloudSqlInstance != null) return false;
            return this.secret != null ? this.secret.equals(that.secret) : that.secret == null;
        }

        @Override
        public final int hashCode() {
            int result = this.name.hashCode();
            result = 31 * result + (this.cloudSqlInstance != null ? this.cloudSqlInstance.hashCode() : 0);
            result = 31 * result + (this.secret != null ? this.secret.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/cloud_run_v2_service/CloudRunV2ServiceTemplateVolumes.java <==
package com.hashicorp.cdktf.providers.google.cloud_run_v2_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:13.029Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.cloudRunV2Service.CloudRunV2ServiceTemplateVolumes")
@software.amazon.jsii.Jsii.Proxy(CloudRunV2ServiceTemplateVolumes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CloudRunV2ServiceTemplateVolumes extends software.amazon.jsii.JsiiSerializable {

    /**
     * Volume's name.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#name CloudRunV2Service#name}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * cloud_sql_instance block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#cloud_sql_instance CloudRunV2Service#cloud_sql_instance}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance getCloudSqlInstance() {
        return null;
    }

    /**
     * gcs block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#gcs CloudRunV2Service#gcs}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesGcs getGcs() {
        return null;
    }

    /**
     * nfs block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#nfs CloudRunV2Service#nfs}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesNfs getNfs() {
        return null;
    }

    /**
     * secret block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#secret CloudRunV2Service#secret}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret getSecret() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CloudRunV2ServiceTemplateVolumes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudRunV2ServiceTemplateVolumes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CloudRunV2ServiceTemplateVolumes> {
        java.lang.String name;
        com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance cloudSqlInstance;
        com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesGcs gcs;
        com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesNfs nfs;
        com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret secret;

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateVolumes#getName}
         * @param name Volume's name. This parameter is required.
         *             Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#name CloudRunV2Service#name}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateVolumes#getCloudSqlInstance}
         * @param cloudSqlInstance cloud_sql_instance block.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#cloud_sql_instance CloudRunV2Service#cloud_sql_instance}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudSqlInstance(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance cloudSqlInstance) {
            this.cloudSqlInstance = cloudSqlInstance;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateVolumes#getGcs}
         * @param gcs gcs block.
         *            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#gcs CloudRunV2Service#gcs}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder gcs(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesGcs gcs) {
            this.gcs = gcs;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateVolumes#getNfs}
         * @param nfs nfs block.
         *            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#nfs CloudRunV2Service#nfs}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nfs(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesNfs nfs) {
            this.nfs = nfs;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateVolumes#getSecret}
         * @param secret secret block.
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#secret CloudRunV2Service#secret}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder secret(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret secret) {
            this.secret = secret;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudRunV2ServiceTemplateVolumes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CloudRunV2ServiceTemplateVolumes build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CloudRunV2ServiceTemplateVolumes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudRunV2ServiceTemplateVolumes {
        private final java.lang.String name;
        private final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance cloudSqlInstance;
        private final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesGcs gcs;
        private final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesNfs nfs;
        private final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret secret;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cloudSqlInstance = software.amazon.jsii.Kernel.get(this, "cloudSqlInstance", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance.class));
            this.gcs = software.amazon.jsii.Kernel.get(this, "gcs", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesGcs.class));
            this.nfs = software.amazon.jsii.Kernel.get(this, "nfs", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesNfs.class));
            this.secret = software.amazon.jsii.Kernel.get(this, "secret", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.cloudSqlInstance = builder.cloudSqlInstance;
            this.gcs = builder.gcs;
            this.nfs = builder.nfs;
            this.secret = builder.secret;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesCloudSqlInstance getCloudSqlInstance() {
            return this.cloudSqlInstance;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesGcs getGcs() {
            return this.gcs;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesNfs getNfs() {
            return this.nfs;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.cloud_run_v2_service.CloudRunV2ServiceTemplateVolumesSecret getSecret() {
            return this.secret;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("name", om.valueToTree(this.getName()));
            if (this.getCloudSqlInstance() != null) {
                data.set("cloudSqlInstance", om.valueToTree(this.getCloudSqlInstance()));
            }
            if (this.getGcs() != null) {
                data.set("gcs", om.valueToTree(this.getGcs()));
            }
            if (this.getNfs() != null) {
                data.set("nfs", om.valueToTree(this.getNfs()));
            }
            if (this.getSecret() != null) {
                data.set("secret", om.valueToTree(this.getSecret()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.cloudRunV2Service.CloudRunV2ServiceTemplateVolumes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudRunV2ServiceTemplateVolumes.Jsii$Proxy that = (CloudRunV2ServiceTemplateVolumes.Jsii$Proxy) o;

            if (!name.equals(that.name)) return false;
            if (this.cloudSqlInstance != null ? !this.cloudSqlInstance.equals(that.cloudSqlInstance) : that.cloudSqlInstance != null) return false;
            if (this.gcs != null ? !this.gcs.equals(that.gcs) : that.gcs != null) return false;
            if (this.nfs != null ? !this.nfs.equals(that.nfs) : that.nfs != null) return false;
            return this.secret != null ? this.secret.equals(that.secret) : that.secret == null;
        }

        @Override
        public final int hashCode() {
            int result = this.name.hashCode();
            result = 31 * result + (this.cloudSqlInstance != null ? this.cloudSqlInstance.hashCode() : 0);
            result = 31 * result + (this.gcs != null ? this.gcs.hashCode() : 0);
            result = 31 * result + (this.nfs != null ? this.nfs.hashCode() : 0);
            result = 31 * result + (this.secret != null ? this.secret.hashCode() : 0);
            return result;
        }
    }
}
